.. highlight:: shell

============
Installation
============

Stable release
--------------

To install ``aetcd3``, run this command in your terminal:

.. code-block:: console

    $ python3 -m pip install aetcd3

This is the preferred method to install ``aetcd3``, as it will always install the most recent stable release.

If you don't have `pip`_ installed, this `pip installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _pip installation guide: https://pip.pypa.io/en/stable/installing/


From sources
------------

The sources for ``aetcd3`` can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/martyanov/aetcd3

Or download the `tarball`_:

.. code-block:: console

    $ curl -OL https://github.com/martyanov/aetcd3/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python3 setup.py install

.. _Github repo: https://github.com/martyanov/aetcd3
.. _tarball: https://github.com/martyanov/aetcd3/tarball/master
